# coding: utf-8

"""
    Cudo Compute service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from cudo_compute.configuration import Configuration


class VMMonitoringItem(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'cpu': 'float',
        'disk_rd_bytes': 'int',
        'disk_rd_iops': 'int',
        'disk_wr_bytes': 'int',
        'disk_wr_iops': 'int',
        'memory': 'int',
        'net_rx': 'int',
        'net_tx': 'int',
        'timestamp': 'str'
    }

    attribute_map = {
        'cpu': 'cpu',
        'disk_rd_bytes': 'diskRdBytes',
        'disk_rd_iops': 'diskRdIops',
        'disk_wr_bytes': 'diskWrBytes',
        'disk_wr_iops': 'diskWrIops',
        'memory': 'memory',
        'net_rx': 'netRx',
        'net_tx': 'netTx',
        'timestamp': 'timestamp'
    }

    def __init__(self, cpu=None, disk_rd_bytes=None, disk_rd_iops=None, disk_wr_bytes=None, disk_wr_iops=None, memory=None, net_rx=None, net_tx=None, timestamp=None, _configuration=None):  # noqa: E501
        """VMMonitoringItem - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._cpu = None
        self._disk_rd_bytes = None
        self._disk_rd_iops = None
        self._disk_wr_bytes = None
        self._disk_wr_iops = None
        self._memory = None
        self._net_rx = None
        self._net_tx = None
        self._timestamp = None
        self.discriminator = None

        if cpu is not None:
            self.cpu = cpu
        if disk_rd_bytes is not None:
            self.disk_rd_bytes = disk_rd_bytes
        if disk_rd_iops is not None:
            self.disk_rd_iops = disk_rd_iops
        if disk_wr_bytes is not None:
            self.disk_wr_bytes = disk_wr_bytes
        if disk_wr_iops is not None:
            self.disk_wr_iops = disk_wr_iops
        if memory is not None:
            self.memory = memory
        if net_rx is not None:
            self.net_rx = net_rx
        if net_tx is not None:
            self.net_tx = net_tx
        if timestamp is not None:
            self.timestamp = timestamp

    @property
    def cpu(self):
        """Gets the cpu of this VMMonitoringItem.  # noqa: E501


        :return: The cpu of this VMMonitoringItem.  # noqa: E501
        :rtype: float
        """
        return self._cpu

    @cpu.setter
    def cpu(self, cpu):
        """Sets the cpu of this VMMonitoringItem.


        :param cpu: The cpu of this VMMonitoringItem.  # noqa: E501
        :type: float
        """

        self._cpu = cpu

    @property
    def disk_rd_bytes(self):
        """Gets the disk_rd_bytes of this VMMonitoringItem.  # noqa: E501


        :return: The disk_rd_bytes of this VMMonitoringItem.  # noqa: E501
        :rtype: int
        """
        return self._disk_rd_bytes

    @disk_rd_bytes.setter
    def disk_rd_bytes(self, disk_rd_bytes):
        """Sets the disk_rd_bytes of this VMMonitoringItem.


        :param disk_rd_bytes: The disk_rd_bytes of this VMMonitoringItem.  # noqa: E501
        :type: int
        """

        self._disk_rd_bytes = disk_rd_bytes

    @property
    def disk_rd_iops(self):
        """Gets the disk_rd_iops of this VMMonitoringItem.  # noqa: E501


        :return: The disk_rd_iops of this VMMonitoringItem.  # noqa: E501
        :rtype: int
        """
        return self._disk_rd_iops

    @disk_rd_iops.setter
    def disk_rd_iops(self, disk_rd_iops):
        """Sets the disk_rd_iops of this VMMonitoringItem.


        :param disk_rd_iops: The disk_rd_iops of this VMMonitoringItem.  # noqa: E501
        :type: int
        """

        self._disk_rd_iops = disk_rd_iops

    @property
    def disk_wr_bytes(self):
        """Gets the disk_wr_bytes of this VMMonitoringItem.  # noqa: E501


        :return: The disk_wr_bytes of this VMMonitoringItem.  # noqa: E501
        :rtype: int
        """
        return self._disk_wr_bytes

    @disk_wr_bytes.setter
    def disk_wr_bytes(self, disk_wr_bytes):
        """Sets the disk_wr_bytes of this VMMonitoringItem.


        :param disk_wr_bytes: The disk_wr_bytes of this VMMonitoringItem.  # noqa: E501
        :type: int
        """

        self._disk_wr_bytes = disk_wr_bytes

    @property
    def disk_wr_iops(self):
        """Gets the disk_wr_iops of this VMMonitoringItem.  # noqa: E501


        :return: The disk_wr_iops of this VMMonitoringItem.  # noqa: E501
        :rtype: int
        """
        return self._disk_wr_iops

    @disk_wr_iops.setter
    def disk_wr_iops(self, disk_wr_iops):
        """Sets the disk_wr_iops of this VMMonitoringItem.


        :param disk_wr_iops: The disk_wr_iops of this VMMonitoringItem.  # noqa: E501
        :type: int
        """

        self._disk_wr_iops = disk_wr_iops

    @property
    def memory(self):
        """Gets the memory of this VMMonitoringItem.  # noqa: E501


        :return: The memory of this VMMonitoringItem.  # noqa: E501
        :rtype: int
        """
        return self._memory

    @memory.setter
    def memory(self, memory):
        """Sets the memory of this VMMonitoringItem.


        :param memory: The memory of this VMMonitoringItem.  # noqa: E501
        :type: int
        """

        self._memory = memory

    @property
    def net_rx(self):
        """Gets the net_rx of this VMMonitoringItem.  # noqa: E501


        :return: The net_rx of this VMMonitoringItem.  # noqa: E501
        :rtype: int
        """
        return self._net_rx

    @net_rx.setter
    def net_rx(self, net_rx):
        """Sets the net_rx of this VMMonitoringItem.


        :param net_rx: The net_rx of this VMMonitoringItem.  # noqa: E501
        :type: int
        """

        self._net_rx = net_rx

    @property
    def net_tx(self):
        """Gets the net_tx of this VMMonitoringItem.  # noqa: E501


        :return: The net_tx of this VMMonitoringItem.  # noqa: E501
        :rtype: int
        """
        return self._net_tx

    @net_tx.setter
    def net_tx(self, net_tx):
        """Sets the net_tx of this VMMonitoringItem.


        :param net_tx: The net_tx of this VMMonitoringItem.  # noqa: E501
        :type: int
        """

        self._net_tx = net_tx

    @property
    def timestamp(self):
        """Gets the timestamp of this VMMonitoringItem.  # noqa: E501


        :return: The timestamp of this VMMonitoringItem.  # noqa: E501
        :rtype: str
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this VMMonitoringItem.


        :param timestamp: The timestamp of this VMMonitoringItem.  # noqa: E501
        :type: str
        """

        self._timestamp = timestamp

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(VMMonitoringItem, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VMMonitoringItem):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, VMMonitoringItem):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Cudo Compute service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from src.cudo_compute.api_client import ApiClient


class VirtualMachinesApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def attach_security_group(self, project_id, id, **kwargs):  # noqa: E501
        """Attach security group to VM  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.attach_security_group(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :param str security_group_id:
        :return: AttachSecurityGroupResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.attach_security_group_with_http_info(project_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.attach_security_group_with_http_info(project_id, id, **kwargs)  # noqa: E501
            return data

    def attach_security_group_with_http_info(self, project_id, id, **kwargs):  # noqa: E501
        """Attach security group to VM  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.attach_security_group_with_http_info(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :param str security_group_id:
        :return: AttachSecurityGroupResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'id', 'security_group_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method attach_security_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in params or
                                                       params['project_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project_id` when calling `attach_security_group`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `attach_security_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'security_group_id' in params:
            query_params.append(('securityGroupId', params['security_group_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/vm/{id}/security-group/attach', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AttachSecurityGroupResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def connect_vm(self, project_id, id, **kwargs):  # noqa: E501
        """Connect via VNC  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.connect_vm(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :param str connection_id:
        :return: ConnectVMResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.connect_vm_with_http_info(project_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.connect_vm_with_http_info(project_id, id, **kwargs)  # noqa: E501
            return data

    def connect_vm_with_http_info(self, project_id, id, **kwargs):  # noqa: E501
        """Connect via VNC  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.connect_vm_with_http_info(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :param str connection_id:
        :return: ConnectVMResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'id', 'connection_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method connect_vm" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in params or
                                                       params['project_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project_id` when calling `connect_vm`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `connect_vm`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'connection_id' in params:
            query_params.append(('connectionId', params['connection_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/vms/{id}/connect', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ConnectVMResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def count_vms(self, project_id, **kwargs):  # noqa: E501
        """Count  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.count_vms(project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :return: CountVMsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.count_vms_with_http_info(project_id, **kwargs)  # noqa: E501
        else:
            (data) = self.count_vms_with_http_info(project_id, **kwargs)  # noqa: E501
            return data

    def count_vms_with_http_info(self, project_id, **kwargs):  # noqa: E501
        """Count  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.count_vms_with_http_info(project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :return: CountVMsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method count_vms" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in params or
                                                       params['project_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project_id` when calling `count_vms`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/count-vms', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CountVMsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_private_vm_image(self, project_id, vm_id, id, **kwargs):  # noqa: E501
        """Create private VM image  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_private_vm_image(project_id, vm_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str vm_id: (required)
        :param str id: (required)
        :param str description:
        :return: CreatePrivateVMImageResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_private_vm_image_with_http_info(project_id, vm_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.create_private_vm_image_with_http_info(project_id, vm_id, id, **kwargs)  # noqa: E501
            return data

    def create_private_vm_image_with_http_info(self, project_id, vm_id, id, **kwargs):  # noqa: E501
        """Create private VM image  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_private_vm_image_with_http_info(project_id, vm_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str vm_id: (required)
        :param str id: (required)
        :param str description:
        :return: CreatePrivateVMImageResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'vm_id', 'id', 'description']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_private_vm_image" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in params or
                                                       params['project_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project_id` when calling `create_private_vm_image`")  # noqa: E501
        # verify the required parameter 'vm_id' is set
        if self.api_client.client_side_validation and ('vm_id' not in params or
                                                       params['vm_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `vm_id` when calling `create_private_vm_image`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `create_private_vm_image`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501

        query_params = []
        if 'vm_id' in params:
            query_params.append(('vmId', params['vm_id']))  # noqa: E501
        if 'id' in params:
            query_params.append(('id', params['id']))  # noqa: E501
        if 'description' in params:
            query_params.append(('description', params['description']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/images', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CreatePrivateVMImageResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_vm(self, project_id, create_vm_body, **kwargs):  # noqa: E501
        """Create virtual machine  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_vm(project_id, create_vm_body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param CreateVMBody create_vm_body: (required)
        :return: CreateVMResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_vm_with_http_info(project_id, create_vm_body, **kwargs)  # noqa: E501
        else:
            (data) = self.create_vm_with_http_info(project_id, create_vm_body, **kwargs)  # noqa: E501
            return data

    def create_vm_with_http_info(self, project_id, create_vm_body, **kwargs):  # noqa: E501
        """Create virtual machine  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_vm_with_http_info(project_id, create_vm_body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param CreateVMBody create_vm_body: (required)
        :return: CreateVMResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'create_vm_body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_vm" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in params or
                                                       params['project_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project_id` when calling `create_vm`")  # noqa: E501
        # verify the required parameter 'create_vm_body' is set
        if self.api_client.client_side_validation and ('create_vm_body' not in params or
                                                       params['create_vm_body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `create_vm_body` when calling `create_vm`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'create_vm_body' in params:
            body_params = params['create_vm_body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/vm', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CreateVMResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_private_vm_image(self, project_id, id, **kwargs):  # noqa: E501
        """Delete private VM image  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_private_vm_image(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :return: DeletePrivateVMImageResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_private_vm_image_with_http_info(project_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_private_vm_image_with_http_info(project_id, id, **kwargs)  # noqa: E501
            return data

    def delete_private_vm_image_with_http_info(self, project_id, id, **kwargs):  # noqa: E501
        """Delete private VM image  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_private_vm_image_with_http_info(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :return: DeletePrivateVMImageResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_private_vm_image" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in params or
                                                       params['project_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project_id` when calling `delete_private_vm_image`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `delete_private_vm_image`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/images/{id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeletePrivateVMImageResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def detach_security_group(self, project_id, id, **kwargs):  # noqa: E501
        """Attach security group to VM  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.detach_security_group(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :param str security_group_id:
        :return: DetachSecurityGroupResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.detach_security_group_with_http_info(project_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.detach_security_group_with_http_info(project_id, id, **kwargs)  # noqa: E501
            return data

    def detach_security_group_with_http_info(self, project_id, id, **kwargs):  # noqa: E501
        """Attach security group to VM  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.detach_security_group_with_http_info(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :param str security_group_id:
        :return: DetachSecurityGroupResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'id', 'security_group_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method detach_security_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in params or
                                                       params['project_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project_id` when calling `detach_security_group`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `detach_security_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'security_group_id' in params:
            query_params.append(('securityGroupId', params['security_group_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/vm/{id}/security-group/detach', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DetachSecurityGroupResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_private_vm_image(self, project_id, id, **kwargs):  # noqa: E501
        """Get private VM image  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_private_vm_image(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :return: GetPrivateVMImageResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_private_vm_image_with_http_info(project_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_private_vm_image_with_http_info(project_id, id, **kwargs)  # noqa: E501
            return data

    def get_private_vm_image_with_http_info(self, project_id, id, **kwargs):  # noqa: E501
        """Get private VM image  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_private_vm_image_with_http_info(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :return: GetPrivateVMImageResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_private_vm_image" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in params or
                                                       params['project_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project_id` when calling `get_private_vm_image`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `get_private_vm_image`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/images/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetPrivateVMImageResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_vm(self, project_id, id, **kwargs):  # noqa: E501
        """Get  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_vm(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :return: GetVMResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_vm_with_http_info(project_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_vm_with_http_info(project_id, id, **kwargs)  # noqa: E501
            return data

    def get_vm_with_http_info(self, project_id, id, **kwargs):  # noqa: E501
        """Get  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_vm_with_http_info(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :return: GetVMResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_vm" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in params or
                                                       params['project_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project_id` when calling `get_vm`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `get_vm`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/vms/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetVMResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_private_vm_images(self, project_id, **kwargs):  # noqa: E501
        """List private VM images  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_private_vm_images(project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param int page_number:
        :param int page_size:
        :return: ListPrivateVMImagesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_private_vm_images_with_http_info(project_id, **kwargs)  # noqa: E501
        else:
            (data) = self.list_private_vm_images_with_http_info(project_id, **kwargs)  # noqa: E501
            return data

    def list_private_vm_images_with_http_info(self, project_id, **kwargs):  # noqa: E501
        """List private VM images  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_private_vm_images_with_http_info(project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param int page_number:
        :param int page_size:
        :return: ListPrivateVMImagesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'page_number', 'page_size']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_private_vm_images" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in params or
                                                       params['project_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project_id` when calling `list_private_vm_images`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501

        query_params = []
        if 'page_number' in params:
            query_params.append(('pageNumber', params['page_number']))  # noqa: E501
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/images', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListPrivateVMImagesResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_public_vm_images(self, **kwargs):  # noqa: E501
        """List public VM images  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_public_vm_images(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: ListPublicVMImagesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_public_vm_images_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.list_public_vm_images_with_http_info(**kwargs)  # noqa: E501
            return data

    def list_public_vm_images_with_http_info(self, **kwargs):  # noqa: E501
        """List public VM images  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_public_vm_images_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: ListPublicVMImagesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_public_vm_images" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/vms/public-images', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListPublicVMImagesResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_vm_data_centers(self, **kwargs):  # noqa: E501
        """List data centers  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_vm_data_centers(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[str] region_id:
        :param bool renewable_energy:
        :return: ListVMDataCentersResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_vm_data_centers_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.list_vm_data_centers_with_http_info(**kwargs)  # noqa: E501
            return data

    def list_vm_data_centers_with_http_info(self, **kwargs):  # noqa: E501
        """List data centers  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_vm_data_centers_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[str] region_id:
        :param bool renewable_energy:
        :return: ListVMDataCentersResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['region_id', 'renewable_energy']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_vm_data_centers" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'region_id' in params:
            query_params.append(('regionId', params['region_id']))  # noqa: E501
            collection_formats['regionId'] = 'multi'  # noqa: E501
        if 'renewable_energy' in params:
            query_params.append(('renewableEnergy', params['renewable_energy']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/vms/data-centers', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListVMDataCentersResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_vm_disks(self, project_id, id, **kwargs):  # noqa: E501
        """List disks attached to VM  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_vm_disks(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :return: ListVMDisksResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_vm_disks_with_http_info(project_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.list_vm_disks_with_http_info(project_id, id, **kwargs)  # noqa: E501
            return data

    def list_vm_disks_with_http_info(self, project_id, id, **kwargs):  # noqa: E501
        """List disks attached to VM  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_vm_disks_with_http_info(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :return: ListVMDisksResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_vm_disks" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in params or
                                                       params['project_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project_id` when calling `list_vm_disks`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `list_vm_disks`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/vms/{id}/disks', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListVMDisksResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_vm_machine_types(self, memory_gib, vcpu, **kwargs):  # noqa: E501
        """List machine types  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_vm_machine_types(memory_gib, vcpu, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int memory_gib: (required)
        :param int vcpu: (required)
        :param str cpu_model:
        :param int gpu:
        :param str gpu_model:
        :param str order_by:
        :param int page_number:
        :param int page_size:
        :param str region_id:
        :param int storage_gib:
        :param str data_center_id:
        :param bool public_ipv4:
        :return: ListVMMachineTypesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_vm_machine_types_with_http_info(memory_gib, vcpu, **kwargs)  # noqa: E501
        else:
            (data) = self.list_vm_machine_types_with_http_info(memory_gib, vcpu, **kwargs)  # noqa: E501
            return data

    def list_vm_machine_types_with_http_info(self, memory_gib, vcpu, **kwargs):  # noqa: E501
        """List machine types  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_vm_machine_types_with_http_info(memory_gib, vcpu, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int memory_gib: (required)
        :param int vcpu: (required)
        :param str cpu_model:
        :param int gpu:
        :param str gpu_model:
        :param str order_by:
        :param int page_number:
        :param int page_size:
        :param str region_id:
        :param int storage_gib:
        :param str data_center_id:
        :param bool public_ipv4:
        :return: ListVMMachineTypesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['memory_gib', 'vcpu', 'cpu_model', 'gpu', 'gpu_model', 'order_by', 'page_number', 'page_size', 'region_id', 'storage_gib', 'data_center_id', 'public_ipv4']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_vm_machine_types" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'memory_gib' is set
        if self.api_client.client_side_validation and ('memory_gib' not in params or
                                                       params['memory_gib'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `memory_gib` when calling `list_vm_machine_types`")  # noqa: E501
        # verify the required parameter 'vcpu' is set
        if self.api_client.client_side_validation and ('vcpu' not in params or
                                                       params['vcpu'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `vcpu` when calling `list_vm_machine_types`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'cpu_model' in params:
            query_params.append(('cpuModel', params['cpu_model']))  # noqa: E501
        if 'gpu' in params:
            query_params.append(('gpu', params['gpu']))  # noqa: E501
        if 'gpu_model' in params:
            query_params.append(('gpuModel', params['gpu_model']))  # noqa: E501
        if 'memory_gib' in params:
            query_params.append(('memoryGib', params['memory_gib']))  # noqa: E501
        if 'order_by' in params:
            query_params.append(('orderBy', params['order_by']))  # noqa: E501
        if 'page_number' in params:
            query_params.append(('pageNumber', params['page_number']))  # noqa: E501
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501
        if 'region_id' in params:
            query_params.append(('regionId', params['region_id']))  # noqa: E501
        if 'storage_gib' in params:
            query_params.append(('storageGib', params['storage_gib']))  # noqa: E501
        if 'vcpu' in params:
            query_params.append(('vcpu', params['vcpu']))  # noqa: E501
        if 'data_center_id' in params:
            query_params.append(('dataCenterId', params['data_center_id']))  # noqa: E501
        if 'public_ipv4' in params:
            query_params.append(('publicIpv4', params['public_ipv4']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/vms/machine-types', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListVMMachineTypesResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_vms(self, project_id, **kwargs):  # noqa: E501
        """List  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_vms(project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str network_id:
        :return: ListVMsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_vms_with_http_info(project_id, **kwargs)  # noqa: E501
        else:
            (data) = self.list_vms_with_http_info(project_id, **kwargs)  # noqa: E501
            return data

    def list_vms_with_http_info(self, project_id, **kwargs):  # noqa: E501
        """List  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_vms_with_http_info(project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str network_id:
        :return: ListVMsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'network_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_vms" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in params or
                                                       params['project_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project_id` when calling `list_vms`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501

        query_params = []
        if 'network_id' in params:
            query_params.append(('networkId', params['network_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/vms', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListVMsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def monitor_vm(self, project_id, id, **kwargs):  # noqa: E501
        """Monitor  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.monitor_vm(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :return: MonitorVMResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.monitor_vm_with_http_info(project_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.monitor_vm_with_http_info(project_id, id, **kwargs)  # noqa: E501
            return data

    def monitor_vm_with_http_info(self, project_id, id, **kwargs):  # noqa: E501
        """Monitor  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.monitor_vm_with_http_info(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :return: MonitorVMResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method monitor_vm" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in params or
                                                       params['project_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project_id` when calling `monitor_vm`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `monitor_vm`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/vms/{id}/monitor', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='MonitorVMResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def reboot_vm(self, project_id, id, **kwargs):  # noqa: E501
        """Reboot  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.reboot_vm(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :return: RebootVMResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.reboot_vm_with_http_info(project_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.reboot_vm_with_http_info(project_id, id, **kwargs)  # noqa: E501
            return data

    def reboot_vm_with_http_info(self, project_id, id, **kwargs):  # noqa: E501
        """Reboot  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.reboot_vm_with_http_info(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :return: RebootVMResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method reboot_vm" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in params or
                                                       params['project_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project_id` when calling `reboot_vm`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `reboot_vm`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/vms/{id}/reboot', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RebootVMResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def resize_vm(self, project_id, id, **kwargs):  # noqa: E501
        """Resize vCPU and memory of VM  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.resize_vm(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :param int vcpus:
        :param int memory_gib:
        :return: ResizeVMResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.resize_vm_with_http_info(project_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.resize_vm_with_http_info(project_id, id, **kwargs)  # noqa: E501
            return data

    def resize_vm_with_http_info(self, project_id, id, **kwargs):  # noqa: E501
        """Resize vCPU and memory of VM  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.resize_vm_with_http_info(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :param int vcpus:
        :param int memory_gib:
        :return: ResizeVMResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'id', 'vcpus', 'memory_gib']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method resize_vm" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in params or
                                                       params['project_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project_id` when calling `resize_vm`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `resize_vm`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'vcpus' in params:
            query_params.append(('vcpus', params['vcpus']))  # noqa: E501
        if 'memory_gib' in params:
            query_params.append(('memoryGib', params['memory_gib']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/vms/{id}/resize', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResizeVMResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def resize_vm_disk(self, project_id, id, **kwargs):  # noqa: E501
        """Resize a VM's disk  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.resize_vm_disk(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :param str disk_id:
        :param int size_gib:
        :return: ResizeVMDiskResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.resize_vm_disk_with_http_info(project_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.resize_vm_disk_with_http_info(project_id, id, **kwargs)  # noqa: E501
            return data

    def resize_vm_disk_with_http_info(self, project_id, id, **kwargs):  # noqa: E501
        """Resize a VM's disk  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.resize_vm_disk_with_http_info(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :param str disk_id:
        :param int size_gib:
        :return: ResizeVMDiskResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'id', 'disk_id', 'size_gib']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method resize_vm_disk" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in params or
                                                       params['project_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project_id` when calling `resize_vm_disk`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `resize_vm_disk`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'disk_id' in params:
            query_params.append(('diskId', params['disk_id']))  # noqa: E501
        if 'size_gib' in params:
            query_params.append(('sizeGib', params['size_gib']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/vms/{id}/disks', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResizeVMDiskResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def start_vm(self, project_id, id, **kwargs):  # noqa: E501
        """Start  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.start_vm(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :return: StartVMResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.start_vm_with_http_info(project_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.start_vm_with_http_info(project_id, id, **kwargs)  # noqa: E501
            return data

    def start_vm_with_http_info(self, project_id, id, **kwargs):  # noqa: E501
        """Start  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.start_vm_with_http_info(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :return: StartVMResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method start_vm" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in params or
                                                       params['project_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project_id` when calling `start_vm`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `start_vm`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/vms/{id}/start', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='StartVMResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def stop_vm(self, project_id, id, **kwargs):  # noqa: E501
        """Stop  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.stop_vm(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :return: StopVMResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.stop_vm_with_http_info(project_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.stop_vm_with_http_info(project_id, id, **kwargs)  # noqa: E501
            return data

    def stop_vm_with_http_info(self, project_id, id, **kwargs):  # noqa: E501
        """Stop  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.stop_vm_with_http_info(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :return: StopVMResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method stop_vm" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in params or
                                                       params['project_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project_id` when calling `stop_vm`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `stop_vm`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/vms/{id}/stop', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='StopVMResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def terminate_vm(self, project_id, id, **kwargs):  # noqa: E501
        """Terminate  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.terminate_vm(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :return: TerminateVMResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.terminate_vm_with_http_info(project_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.terminate_vm_with_http_info(project_id, id, **kwargs)  # noqa: E501
            return data

    def terminate_vm_with_http_info(self, project_id, id, **kwargs):  # noqa: E501
        """Terminate  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.terminate_vm_with_http_info(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :return: TerminateVMResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method terminate_vm" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in params or
                                                       params['project_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project_id` when calling `terminate_vm`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `terminate_vm`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/vms/{id}/terminate', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TerminateVMResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_private_vm_image(self, project_id, id, **kwargs):  # noqa: E501
        """Update private VM image  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_private_vm_image(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :param str description:
        :return: UpdatePrivateVMImageResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_private_vm_image_with_http_info(project_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_private_vm_image_with_http_info(project_id, id, **kwargs)  # noqa: E501
            return data

    def update_private_vm_image_with_http_info(self, project_id, id, **kwargs):  # noqa: E501
        """Update private VM image  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_private_vm_image_with_http_info(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :param str description:
        :return: UpdatePrivateVMImageResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'id', 'description']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_private_vm_image" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in params or
                                                       params['project_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project_id` when calling `update_private_vm_image`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `update_private_vm_image`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'description' in params:
            query_params.append(('description', params['description']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/images/{id}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UpdatePrivateVMImageResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_vm_metadata(self, project_id, id, update_vm_metadata_body, **kwargs):  # noqa: E501
        """Update VM metadata  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_vm_metadata(project_id, id, update_vm_metadata_body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :param UpdateVMMetadataBody update_vm_metadata_body: (required)
        :return: UpdateVMMetadataResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_vm_metadata_with_http_info(project_id, id, update_vm_metadata_body, **kwargs)  # noqa: E501
        else:
            (data) = self.update_vm_metadata_with_http_info(project_id, id, update_vm_metadata_body, **kwargs)  # noqa: E501
            return data

    def update_vm_metadata_with_http_info(self, project_id, id, update_vm_metadata_body, **kwargs):  # noqa: E501
        """Update VM metadata  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_vm_metadata_with_http_info(project_id, id, update_vm_metadata_body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :param UpdateVMMetadataBody update_vm_metadata_body: (required)
        :return: UpdateVMMetadataResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'id', 'update_vm_metadata_body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_vm_metadata" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in params or
                                                       params['project_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project_id` when calling `update_vm_metadata`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `update_vm_metadata`")  # noqa: E501
        # verify the required parameter 'update_vm_metadata_body' is set
        if self.api_client.client_side_validation and ('update_vm_metadata_body' not in params or
                                                       params['update_vm_metadata_body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `update_vm_metadata_body` when calling `update_vm_metadata`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_vm_metadata_body' in params:
            body_params = params['update_vm_metadata_body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/vm/{id}/metadata', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UpdateVMMetadataResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Cudo Compute service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from cudo_compute.configuration import Configuration


class DataCenter(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'create_by': 'str',
        'lng_lat': 'Point',
        'one_frontend_id': 'str',
        'region_id': 'str',
        'renewable_energy': 'bool',
        'supplier_name': 'str'
    }

    attribute_map = {
        'create_by': 'createBy',
        'lng_lat': 'lngLat',
        'one_frontend_id': 'oneFrontendId',
        'region_id': 'regionId',
        'renewable_energy': 'renewableEnergy',
        'supplier_name': 'supplierName'
    }

    def __init__(self, create_by=None, lng_lat=None, one_frontend_id=None, region_id=None, renewable_energy=None, supplier_name=None, _configuration=None):  # noqa: E501
        """DataCenter - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._create_by = None
        self._lng_lat = None
        self._one_frontend_id = None
        self._region_id = None
        self._renewable_energy = None
        self._supplier_name = None
        self.discriminator = None

        if create_by is not None:
            self.create_by = create_by
        if lng_lat is not None:
            self.lng_lat = lng_lat
        self.one_frontend_id = one_frontend_id
        if region_id is not None:
            self.region_id = region_id
        if renewable_energy is not None:
            self.renewable_energy = renewable_energy
        if supplier_name is not None:
            self.supplier_name = supplier_name

    @property
    def create_by(self):
        """Gets the create_by of this DataCenter.  # noqa: E501


        :return: The create_by of this DataCenter.  # noqa: E501
        :rtype: str
        """
        return self._create_by

    @create_by.setter
    def create_by(self, create_by):
        """Sets the create_by of this DataCenter.


        :param create_by: The create_by of this DataCenter.  # noqa: E501
        :type: str
        """

        self._create_by = create_by

    @property
    def lng_lat(self):
        """Gets the lng_lat of this DataCenter.  # noqa: E501


        :return: The lng_lat of this DataCenter.  # noqa: E501
        :rtype: Point
        """
        return self._lng_lat

    @lng_lat.setter
    def lng_lat(self, lng_lat):
        """Sets the lng_lat of this DataCenter.


        :param lng_lat: The lng_lat of this DataCenter.  # noqa: E501
        :type: Point
        """

        self._lng_lat = lng_lat

    @property
    def one_frontend_id(self):
        """Gets the one_frontend_id of this DataCenter.  # noqa: E501


        :return: The one_frontend_id of this DataCenter.  # noqa: E501
        :rtype: str
        """
        return self._one_frontend_id

    @one_frontend_id.setter
    def one_frontend_id(self, one_frontend_id):
        """Sets the one_frontend_id of this DataCenter.


        :param one_frontend_id: The one_frontend_id of this DataCenter.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and one_frontend_id is None:
            raise ValueError("Invalid value for `one_frontend_id`, must not be `None`")  # noqa: E501

        self._one_frontend_id = one_frontend_id

    @property
    def region_id(self):
        """Gets the region_id of this DataCenter.  # noqa: E501


        :return: The region_id of this DataCenter.  # noqa: E501
        :rtype: str
        """
        return self._region_id

    @region_id.setter
    def region_id(self, region_id):
        """Sets the region_id of this DataCenter.


        :param region_id: The region_id of this DataCenter.  # noqa: E501
        :type: str
        """

        self._region_id = region_id

    @property
    def renewable_energy(self):
        """Gets the renewable_energy of this DataCenter.  # noqa: E501


        :return: The renewable_energy of this DataCenter.  # noqa: E501
        :rtype: bool
        """
        return self._renewable_energy

    @renewable_energy.setter
    def renewable_energy(self, renewable_energy):
        """Sets the renewable_energy of this DataCenter.


        :param renewable_energy: The renewable_energy of this DataCenter.  # noqa: E501
        :type: bool
        """

        self._renewable_energy = renewable_energy

    @property
    def supplier_name(self):
        """Gets the supplier_name of this DataCenter.  # noqa: E501


        :return: The supplier_name of this DataCenter.  # noqa: E501
        :rtype: str
        """
        return self._supplier_name

    @supplier_name.setter
    def supplier_name(self, supplier_name):
        """Sets the supplier_name of this DataCenter.


        :param supplier_name: The supplier_name of this DataCenter.  # noqa: E501
        :type: str
        """

        self._supplier_name = supplier_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DataCenter, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DataCenter):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DataCenter):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Cudo Compute service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from cudo_compute.configuration import Configuration


class VM(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'active_state': 'str',
        'boot_disk': 'Disk',
        'boot_disk_size_gib': 'int',
        'cpu_model': 'str',
        'create_by': 'str',
        'datacenter_id': 'str',
        'external_ip_address': 'str',
        'gpu_model': 'str',
        'gpu_quantity': 'int',
        'id': 'str',
        'image_id': 'str',
        'image_name': 'str',
        'init_state': 'str',
        'internal_ip_address': 'str',
        'lcm_state': 'str',
        'machine_type': 'str',
        'memory': 'int',
        'metadata': 'dict(str, str)',
        'nics': 'list[VMNIC]',
        'one_state': 'str',
        'price_hr': 'float',
        'private_image_id': 'str',
        'public_image_id': 'str',
        'public_image_name': 'str',
        'public_ip_address': 'str',
        'region_id': 'str',
        'region_name': 'str',
        'renewable_energy': 'bool',
        'rules': 'list[SecurityGroupRule]',
        'security_group_ids': 'list[str]',
        'short_state': 'str',
        'storage_disks': 'list[Disk]',
        'vcpus': 'int',
        'vm_state': 'VmState'
    }

    attribute_map = {
        'active_state': 'activeState',
        'boot_disk': 'bootDisk',
        'boot_disk_size_gib': 'bootDiskSizeGib',
        'cpu_model': 'cpuModel',
        'create_by': 'createBy',
        'datacenter_id': 'datacenterId',
        'external_ip_address': 'externalIpAddress',
        'gpu_model': 'gpuModel',
        'gpu_quantity': 'gpuQuantity',
        'id': 'id',
        'image_id': 'imageId',
        'image_name': 'imageName',
        'init_state': 'initState',
        'internal_ip_address': 'internalIpAddress',
        'lcm_state': 'lcmState',
        'machine_type': 'machineType',
        'memory': 'memory',
        'metadata': 'metadata',
        'nics': 'nics',
        'one_state': 'oneState',
        'price_hr': 'priceHr',
        'private_image_id': 'privateImageId',
        'public_image_id': 'publicImageId',
        'public_image_name': 'publicImageName',
        'public_ip_address': 'publicIpAddress',
        'region_id': 'regionId',
        'region_name': 'regionName',
        'renewable_energy': 'renewableEnergy',
        'rules': 'rules',
        'security_group_ids': 'securityGroupIds',
        'short_state': 'shortState',
        'storage_disks': 'storageDisks',
        'vcpus': 'vcpus',
        'vm_state': 'vmState'
    }

    def __init__(self, active_state=None, boot_disk=None, boot_disk_size_gib=None, cpu_model=None, create_by=None, datacenter_id=None, external_ip_address=None, gpu_model=None, gpu_quantity=None, id=None, image_id=None, image_name=None, init_state=None, internal_ip_address=None, lcm_state=None, machine_type=None, memory=None, metadata=None, nics=None, one_state=None, price_hr=None, private_image_id=None, public_image_id=None, public_image_name=None, public_ip_address=None, region_id=None, region_name=None, renewable_energy=None, rules=None, security_group_ids=None, short_state=None, storage_disks=None, vcpus=None, vm_state=None, _configuration=None):  # noqa: E501
        """VM - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._active_state = None
        self._boot_disk = None
        self._boot_disk_size_gib = None
        self._cpu_model = None
        self._create_by = None
        self._datacenter_id = None
        self._external_ip_address = None
        self._gpu_model = None
        self._gpu_quantity = None
        self._id = None
        self._image_id = None
        self._image_name = None
        self._init_state = None
        self._internal_ip_address = None
        self._lcm_state = None
        self._machine_type = None
        self._memory = None
        self._metadata = None
        self._nics = None
        self._one_state = None
        self._price_hr = None
        self._private_image_id = None
        self._public_image_id = None
        self._public_image_name = None
        self._public_ip_address = None
        self._region_id = None
        self._region_name = None
        self._renewable_energy = None
        self._rules = None
        self._security_group_ids = None
        self._short_state = None
        self._storage_disks = None
        self._vcpus = None
        self._vm_state = None
        self.discriminator = None

        if active_state is not None:
            self.active_state = active_state
        if boot_disk is not None:
            self.boot_disk = boot_disk
        if boot_disk_size_gib is not None:
            self.boot_disk_size_gib = boot_disk_size_gib
        if cpu_model is not None:
            self.cpu_model = cpu_model
        if create_by is not None:
            self.create_by = create_by
        if datacenter_id is not None:
            self.datacenter_id = datacenter_id
        if external_ip_address is not None:
            self.external_ip_address = external_ip_address
        if gpu_model is not None:
            self.gpu_model = gpu_model
        if gpu_quantity is not None:
            self.gpu_quantity = gpu_quantity
        if id is not None:
            self.id = id
        if image_id is not None:
            self.image_id = image_id
        if image_name is not None:
            self.image_name = image_name
        if init_state is not None:
            self.init_state = init_state
        if internal_ip_address is not None:
            self.internal_ip_address = internal_ip_address
        if lcm_state is not None:
            self.lcm_state = lcm_state
        if machine_type is not None:
            self.machine_type = machine_type
        if memory is not None:
            self.memory = memory
        if metadata is not None:
            self.metadata = metadata
        if nics is not None:
            self.nics = nics
        if one_state is not None:
            self.one_state = one_state
        if price_hr is not None:
            self.price_hr = price_hr
        if private_image_id is not None:
            self.private_image_id = private_image_id
        if public_image_id is not None:
            self.public_image_id = public_image_id
        if public_image_name is not None:
            self.public_image_name = public_image_name
        if public_ip_address is not None:
            self.public_ip_address = public_ip_address
        if region_id is not None:
            self.region_id = region_id
        if region_name is not None:
            self.region_name = region_name
        if renewable_energy is not None:
            self.renewable_energy = renewable_energy
        if rules is not None:
            self.rules = rules
        if security_group_ids is not None:
            self.security_group_ids = security_group_ids
        if short_state is not None:
            self.short_state = short_state
        if storage_disks is not None:
            self.storage_disks = storage_disks
        if vcpus is not None:
            self.vcpus = vcpus
        if vm_state is not None:
            self.vm_state = vm_state

    @property
    def active_state(self):
        """Gets the active_state of this VM.  # noqa: E501


        :return: The active_state of this VM.  # noqa: E501
        :rtype: str
        """
        return self._active_state

    @active_state.setter
    def active_state(self, active_state):
        """Sets the active_state of this VM.


        :param active_state: The active_state of this VM.  # noqa: E501
        :type: str
        """

        self._active_state = active_state

    @property
    def boot_disk(self):
        """Gets the boot_disk of this VM.  # noqa: E501


        :return: The boot_disk of this VM.  # noqa: E501
        :rtype: Disk
        """
        return self._boot_disk

    @boot_disk.setter
    def boot_disk(self, boot_disk):
        """Sets the boot_disk of this VM.


        :param boot_disk: The boot_disk of this VM.  # noqa: E501
        :type: Disk
        """

        self._boot_disk = boot_disk

    @property
    def boot_disk_size_gib(self):
        """Gets the boot_disk_size_gib of this VM.  # noqa: E501


        :return: The boot_disk_size_gib of this VM.  # noqa: E501
        :rtype: int
        """
        return self._boot_disk_size_gib

    @boot_disk_size_gib.setter
    def boot_disk_size_gib(self, boot_disk_size_gib):
        """Sets the boot_disk_size_gib of this VM.


        :param boot_disk_size_gib: The boot_disk_size_gib of this VM.  # noqa: E501
        :type: int
        """

        self._boot_disk_size_gib = boot_disk_size_gib

    @property
    def cpu_model(self):
        """Gets the cpu_model of this VM.  # noqa: E501


        :return: The cpu_model of this VM.  # noqa: E501
        :rtype: str
        """
        return self._cpu_model

    @cpu_model.setter
    def cpu_model(self, cpu_model):
        """Sets the cpu_model of this VM.


        :param cpu_model: The cpu_model of this VM.  # noqa: E501
        :type: str
        """

        self._cpu_model = cpu_model

    @property
    def create_by(self):
        """Gets the create_by of this VM.  # noqa: E501


        :return: The create_by of this VM.  # noqa: E501
        :rtype: str
        """
        return self._create_by

    @create_by.setter
    def create_by(self, create_by):
        """Sets the create_by of this VM.


        :param create_by: The create_by of this VM.  # noqa: E501
        :type: str
        """

        self._create_by = create_by

    @property
    def datacenter_id(self):
        """Gets the datacenter_id of this VM.  # noqa: E501


        :return: The datacenter_id of this VM.  # noqa: E501
        :rtype: str
        """
        return self._datacenter_id

    @datacenter_id.setter
    def datacenter_id(self, datacenter_id):
        """Sets the datacenter_id of this VM.


        :param datacenter_id: The datacenter_id of this VM.  # noqa: E501
        :type: str
        """

        self._datacenter_id = datacenter_id

    @property
    def external_ip_address(self):
        """Gets the external_ip_address of this VM.  # noqa: E501


        :return: The external_ip_address of this VM.  # noqa: E501
        :rtype: str
        """
        return self._external_ip_address

    @external_ip_address.setter
    def external_ip_address(self, external_ip_address):
        """Sets the external_ip_address of this VM.


        :param external_ip_address: The external_ip_address of this VM.  # noqa: E501
        :type: str
        """

        self._external_ip_address = external_ip_address

    @property
    def gpu_model(self):
        """Gets the gpu_model of this VM.  # noqa: E501


        :return: The gpu_model of this VM.  # noqa: E501
        :rtype: str
        """
        return self._gpu_model

    @gpu_model.setter
    def gpu_model(self, gpu_model):
        """Sets the gpu_model of this VM.


        :param gpu_model: The gpu_model of this VM.  # noqa: E501
        :type: str
        """

        self._gpu_model = gpu_model

    @property
    def gpu_quantity(self):
        """Gets the gpu_quantity of this VM.  # noqa: E501


        :return: The gpu_quantity of this VM.  # noqa: E501
        :rtype: int
        """
        return self._gpu_quantity

    @gpu_quantity.setter
    def gpu_quantity(self, gpu_quantity):
        """Sets the gpu_quantity of this VM.


        :param gpu_quantity: The gpu_quantity of this VM.  # noqa: E501
        :type: int
        """

        self._gpu_quantity = gpu_quantity

    @property
    def id(self):
        """Gets the id of this VM.  # noqa: E501


        :return: The id of this VM.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this VM.


        :param id: The id of this VM.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def image_id(self):
        """Gets the image_id of this VM.  # noqa: E501


        :return: The image_id of this VM.  # noqa: E501
        :rtype: str
        """
        return self._image_id

    @image_id.setter
    def image_id(self, image_id):
        """Sets the image_id of this VM.


        :param image_id: The image_id of this VM.  # noqa: E501
        :type: str
        """

        self._image_id = image_id

    @property
    def image_name(self):
        """Gets the image_name of this VM.  # noqa: E501


        :return: The image_name of this VM.  # noqa: E501
        :rtype: str
        """
        return self._image_name

    @image_name.setter
    def image_name(self, image_name):
        """Sets the image_name of this VM.


        :param image_name: The image_name of this VM.  # noqa: E501
        :type: str
        """

        self._image_name = image_name

    @property
    def init_state(self):
        """Gets the init_state of this VM.  # noqa: E501


        :return: The init_state of this VM.  # noqa: E501
        :rtype: str
        """
        return self._init_state

    @init_state.setter
    def init_state(self, init_state):
        """Sets the init_state of this VM.


        :param init_state: The init_state of this VM.  # noqa: E501
        :type: str
        """

        self._init_state = init_state

    @property
    def internal_ip_address(self):
        """Gets the internal_ip_address of this VM.  # noqa: E501


        :return: The internal_ip_address of this VM.  # noqa: E501
        :rtype: str
        """
        return self._internal_ip_address

    @internal_ip_address.setter
    def internal_ip_address(self, internal_ip_address):
        """Sets the internal_ip_address of this VM.


        :param internal_ip_address: The internal_ip_address of this VM.  # noqa: E501
        :type: str
        """

        self._internal_ip_address = internal_ip_address

    @property
    def lcm_state(self):
        """Gets the lcm_state of this VM.  # noqa: E501


        :return: The lcm_state of this VM.  # noqa: E501
        :rtype: str
        """
        return self._lcm_state

    @lcm_state.setter
    def lcm_state(self, lcm_state):
        """Sets the lcm_state of this VM.


        :param lcm_state: The lcm_state of this VM.  # noqa: E501
        :type: str
        """

        self._lcm_state = lcm_state

    @property
    def machine_type(self):
        """Gets the machine_type of this VM.  # noqa: E501


        :return: The machine_type of this VM.  # noqa: E501
        :rtype: str
        """
        return self._machine_type

    @machine_type.setter
    def machine_type(self, machine_type):
        """Sets the machine_type of this VM.


        :param machine_type: The machine_type of this VM.  # noqa: E501
        :type: str
        """

        self._machine_type = machine_type

    @property
    def memory(self):
        """Gets the memory of this VM.  # noqa: E501


        :return: The memory of this VM.  # noqa: E501
        :rtype: int
        """
        return self._memory

    @memory.setter
    def memory(self, memory):
        """Sets the memory of this VM.


        :param memory: The memory of this VM.  # noqa: E501
        :type: int
        """

        self._memory = memory

    @property
    def metadata(self):
        """Gets the metadata of this VM.  # noqa: E501


        :return: The metadata of this VM.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this VM.


        :param metadata: The metadata of this VM.  # noqa: E501
        :type: dict(str, str)
        """

        self._metadata = metadata

    @property
    def nics(self):
        """Gets the nics of this VM.  # noqa: E501


        :return: The nics of this VM.  # noqa: E501
        :rtype: list[VMNIC]
        """
        return self._nics

    @nics.setter
    def nics(self, nics):
        """Sets the nics of this VM.


        :param nics: The nics of this VM.  # noqa: E501
        :type: list[VMNIC]
        """

        self._nics = nics

    @property
    def one_state(self):
        """Gets the one_state of this VM.  # noqa: E501


        :return: The one_state of this VM.  # noqa: E501
        :rtype: str
        """
        return self._one_state

    @one_state.setter
    def one_state(self, one_state):
        """Sets the one_state of this VM.


        :param one_state: The one_state of this VM.  # noqa: E501
        :type: str
        """

        self._one_state = one_state

    @property
    def price_hr(self):
        """Gets the price_hr of this VM.  # noqa: E501


        :return: The price_hr of this VM.  # noqa: E501
        :rtype: float
        """
        return self._price_hr

    @price_hr.setter
    def price_hr(self, price_hr):
        """Sets the price_hr of this VM.


        :param price_hr: The price_hr of this VM.  # noqa: E501
        :type: float
        """

        self._price_hr = price_hr

    @property
    def private_image_id(self):
        """Gets the private_image_id of this VM.  # noqa: E501


        :return: The private_image_id of this VM.  # noqa: E501
        :rtype: str
        """
        return self._private_image_id

    @private_image_id.setter
    def private_image_id(self, private_image_id):
        """Sets the private_image_id of this VM.


        :param private_image_id: The private_image_id of this VM.  # noqa: E501
        :type: str
        """

        self._private_image_id = private_image_id

    @property
    def public_image_id(self):
        """Gets the public_image_id of this VM.  # noqa: E501


        :return: The public_image_id of this VM.  # noqa: E501
        :rtype: str
        """
        return self._public_image_id

    @public_image_id.setter
    def public_image_id(self, public_image_id):
        """Sets the public_image_id of this VM.


        :param public_image_id: The public_image_id of this VM.  # noqa: E501
        :type: str
        """

        self._public_image_id = public_image_id

    @property
    def public_image_name(self):
        """Gets the public_image_name of this VM.  # noqa: E501


        :return: The public_image_name of this VM.  # noqa: E501
        :rtype: str
        """
        return self._public_image_name

    @public_image_name.setter
    def public_image_name(self, public_image_name):
        """Sets the public_image_name of this VM.


        :param public_image_name: The public_image_name of this VM.  # noqa: E501
        :type: str
        """

        self._public_image_name = public_image_name

    @property
    def public_ip_address(self):
        """Gets the public_ip_address of this VM.  # noqa: E501


        :return: The public_ip_address of this VM.  # noqa: E501
        :rtype: str
        """
        return self._public_ip_address

    @public_ip_address.setter
    def public_ip_address(self, public_ip_address):
        """Sets the public_ip_address of this VM.


        :param public_ip_address: The public_ip_address of this VM.  # noqa: E501
        :type: str
        """

        self._public_ip_address = public_ip_address

    @property
    def region_id(self):
        """Gets the region_id of this VM.  # noqa: E501


        :return: The region_id of this VM.  # noqa: E501
        :rtype: str
        """
        return self._region_id

    @region_id.setter
    def region_id(self, region_id):
        """Sets the region_id of this VM.


        :param region_id: The region_id of this VM.  # noqa: E501
        :type: str
        """

        self._region_id = region_id

    @property
    def region_name(self):
        """Gets the region_name of this VM.  # noqa: E501


        :return: The region_name of this VM.  # noqa: E501
        :rtype: str
        """
        return self._region_name

    @region_name.setter
    def region_name(self, region_name):
        """Sets the region_name of this VM.


        :param region_name: The region_name of this VM.  # noqa: E501
        :type: str
        """

        self._region_name = region_name

    @property
    def renewable_energy(self):
        """Gets the renewable_energy of this VM.  # noqa: E501


        :return: The renewable_energy of this VM.  # noqa: E501
        :rtype: bool
        """
        return self._renewable_energy

    @renewable_energy.setter
    def renewable_energy(self, renewable_energy):
        """Sets the renewable_energy of this VM.


        :param renewable_energy: The renewable_energy of this VM.  # noqa: E501
        :type: bool
        """

        self._renewable_energy = renewable_energy

    @property
    def rules(self):
        """Gets the rules of this VM.  # noqa: E501


        :return: The rules of this VM.  # noqa: E501
        :rtype: list[SecurityGroupRule]
        """
        return self._rules

    @rules.setter
    def rules(self, rules):
        """Sets the rules of this VM.


        :param rules: The rules of this VM.  # noqa: E501
        :type: list[SecurityGroupRule]
        """

        self._rules = rules

    @property
    def security_group_ids(self):
        """Gets the security_group_ids of this VM.  # noqa: E501


        :return: The security_group_ids of this VM.  # noqa: E501
        :rtype: list[str]
        """
        return self._security_group_ids

    @security_group_ids.setter
    def security_group_ids(self, security_group_ids):
        """Sets the security_group_ids of this VM.


        :param security_group_ids: The security_group_ids of this VM.  # noqa: E501
        :type: list[str]
        """

        self._security_group_ids = security_group_ids

    @property
    def short_state(self):
        """Gets the short_state of this VM.  # noqa: E501


        :return: The short_state of this VM.  # noqa: E501
        :rtype: str
        """
        return self._short_state

    @short_state.setter
    def short_state(self, short_state):
        """Sets the short_state of this VM.


        :param short_state: The short_state of this VM.  # noqa: E501
        :type: str
        """

        self._short_state = short_state

    @property
    def storage_disks(self):
        """Gets the storage_disks of this VM.  # noqa: E501


        :return: The storage_disks of this VM.  # noqa: E501
        :rtype: list[Disk]
        """
        return self._storage_disks

    @storage_disks.setter
    def storage_disks(self, storage_disks):
        """Sets the storage_disks of this VM.


        :param storage_disks: The storage_disks of this VM.  # noqa: E501
        :type: list[Disk]
        """

        self._storage_disks = storage_disks

    @property
    def vcpus(self):
        """Gets the vcpus of this VM.  # noqa: E501


        :return: The vcpus of this VM.  # noqa: E501
        :rtype: int
        """
        return self._vcpus

    @vcpus.setter
    def vcpus(self, vcpus):
        """Sets the vcpus of this VM.


        :param vcpus: The vcpus of this VM.  # noqa: E501
        :type: int
        """

        self._vcpus = vcpus

    @property
    def vm_state(self):
        """Gets the vm_state of this VM.  # noqa: E501


        :return: The vm_state of this VM.  # noqa: E501
        :rtype: VmState
        """
        return self._vm_state

    @vm_state.setter
    def vm_state(self, vm_state):
        """Sets the vm_state of this VM.


        :param vm_state: The vm_state of this VM.  # noqa: E501
        :type: VmState
        """

        self._vm_state = vm_state

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(VM, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VM):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, VM):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Cudo Compute service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import cudo_compute
from cudo_compute.api.disks_api import DisksApi  # noqa: E501
from cudo_compute.rest import ApiException


class TestDisksApi(unittest.TestCase):
    """DisksApi unit test stubs"""

    def setUp(self):
        self.api = cudo_compute.api.disks_api.DisksApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_attach_storage_disk(self):
        """Test case for attach_storage_disk

        Attach storage disk to VM  # noqa: E501
        """
        pass

    def test_create_disk_snapshot(self):
        """Test case for create_disk_snapshot

        Create Disk Snapshot  # noqa: E501
        """
        pass

    def test_create_storage_disk(self):
        """Test case for create_storage_disk

        Create storage disk  # noqa: E501
        """
        pass

    def test_delete_disk_snapshot(self):
        """Test case for delete_disk_snapshot

        Delete Disk Snapshots  # noqa: E501
        """
        pass

    def test_delete_storage_disk(self):
        """Test case for delete_storage_disk

        Delete storage disk  # noqa: E501
        """
        pass

    def test_detach_storage_disk(self):
        """Test case for detach_storage_disk

        Detach storage disk from VM  # noqa: E501
        """
        pass

    def test_get_disk(self):
        """Test case for get_disk

        List disks  # noqa: E501
        """
        pass

    def test_list_disk_snapshots(self):
        """Test case for list_disk_snapshots

        List Disk Snapshots  # noqa: E501
        """
        pass

    def test_list_disks(self):
        """Test case for list_disks

        List disks  # noqa: E501
        """
        pass

    def test_revert_disk(self):
        """Test case for revert_disk

        Revert Disk to Snapshot  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Cudo Compute service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from cudo_compute.configuration import Configuration


class BillingAccountPaymentMethod(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'card': 'PaymentMethodCard',
        'id': 'str',
        'is_default': 'bool',
        'paypal': 'PaymentMethodPaypal',
        'type': 'str'
    }

    attribute_map = {
        'card': 'card',
        'id': 'id',
        'is_default': 'isDefault',
        'paypal': 'paypal',
        'type': 'type'
    }

    def __init__(self, card=None, id=None, is_default=None, paypal=None, type=None, _configuration=None):  # noqa: E501
        """BillingAccountPaymentMethod - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._card = None
        self._id = None
        self._is_default = None
        self._paypal = None
        self._type = None
        self.discriminator = None

        if card is not None:
            self.card = card
        if id is not None:
            self.id = id
        if is_default is not None:
            self.is_default = is_default
        if paypal is not None:
            self.paypal = paypal
        if type is not None:
            self.type = type

    @property
    def card(self):
        """Gets the card of this BillingAccountPaymentMethod.  # noqa: E501


        :return: The card of this BillingAccountPaymentMethod.  # noqa: E501
        :rtype: PaymentMethodCard
        """
        return self._card

    @card.setter
    def card(self, card):
        """Sets the card of this BillingAccountPaymentMethod.


        :param card: The card of this BillingAccountPaymentMethod.  # noqa: E501
        :type: PaymentMethodCard
        """

        self._card = card

    @property
    def id(self):
        """Gets the id of this BillingAccountPaymentMethod.  # noqa: E501


        :return: The id of this BillingAccountPaymentMethod.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BillingAccountPaymentMethod.


        :param id: The id of this BillingAccountPaymentMethod.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def is_default(self):
        """Gets the is_default of this BillingAccountPaymentMethod.  # noqa: E501


        :return: The is_default of this BillingAccountPaymentMethod.  # noqa: E501
        :rtype: bool
        """
        return self._is_default

    @is_default.setter
    def is_default(self, is_default):
        """Sets the is_default of this BillingAccountPaymentMethod.


        :param is_default: The is_default of this BillingAccountPaymentMethod.  # noqa: E501
        :type: bool
        """

        self._is_default = is_default

    @property
    def paypal(self):
        """Gets the paypal of this BillingAccountPaymentMethod.  # noqa: E501


        :return: The paypal of this BillingAccountPaymentMethod.  # noqa: E501
        :rtype: PaymentMethodPaypal
        """
        return self._paypal

    @paypal.setter
    def paypal(self, paypal):
        """Sets the paypal of this BillingAccountPaymentMethod.


        :param paypal: The paypal of this BillingAccountPaymentMethod.  # noqa: E501
        :type: PaymentMethodPaypal
        """

        self._paypal = paypal

    @property
    def type(self):
        """Gets the type of this BillingAccountPaymentMethod.  # noqa: E501


        :return: The type of this BillingAccountPaymentMethod.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this BillingAccountPaymentMethod.


        :param type: The type of this BillingAccountPaymentMethod.  # noqa: E501
        :type: str
        """

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(BillingAccountPaymentMethod, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BillingAccountPaymentMethod):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, BillingAccountPaymentMethod):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Cudo Compute service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from cudo_compute.configuration import Configuration


class VMDataCenter(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'disk_pool_pricing': 'list[DiskStoragePriceHr]',
        'id': 'str',
        'ipv4_price_hr': 'Decimal',
        'network_pricing': 'list[NetworkPriceHr]',
        'region_id': 'str',
        'renewable_energy': 'bool',
        'supplier_name': 'str'
    }

    attribute_map = {
        'disk_pool_pricing': 'diskPoolPricing',
        'id': 'id',
        'ipv4_price_hr': 'ipv4PriceHr',
        'network_pricing': 'networkPricing',
        'region_id': 'regionId',
        'renewable_energy': 'renewableEnergy',
        'supplier_name': 'supplierName'
    }

    def __init__(self, disk_pool_pricing=None, id=None, ipv4_price_hr=None, network_pricing=None, region_id=None, renewable_energy=None, supplier_name=None, _configuration=None):  # noqa: E501
        """VMDataCenter - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._disk_pool_pricing = None
        self._id = None
        self._ipv4_price_hr = None
        self._network_pricing = None
        self._region_id = None
        self._renewable_energy = None
        self._supplier_name = None
        self.discriminator = None

        if disk_pool_pricing is not None:
            self.disk_pool_pricing = disk_pool_pricing
        self.id = id
        if ipv4_price_hr is not None:
            self.ipv4_price_hr = ipv4_price_hr
        if network_pricing is not None:
            self.network_pricing = network_pricing
        self.region_id = region_id
        self.renewable_energy = renewable_energy
        self.supplier_name = supplier_name

    @property
    def disk_pool_pricing(self):
        """Gets the disk_pool_pricing of this VMDataCenter.  # noqa: E501


        :return: The disk_pool_pricing of this VMDataCenter.  # noqa: E501
        :rtype: list[DiskStoragePriceHr]
        """
        return self._disk_pool_pricing

    @disk_pool_pricing.setter
    def disk_pool_pricing(self, disk_pool_pricing):
        """Sets the disk_pool_pricing of this VMDataCenter.


        :param disk_pool_pricing: The disk_pool_pricing of this VMDataCenter.  # noqa: E501
        :type: list[DiskStoragePriceHr]
        """

        self._disk_pool_pricing = disk_pool_pricing

    @property
    def id(self):
        """Gets the id of this VMDataCenter.  # noqa: E501


        :return: The id of this VMDataCenter.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this VMDataCenter.


        :param id: The id of this VMDataCenter.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def ipv4_price_hr(self):
        """Gets the ipv4_price_hr of this VMDataCenter.  # noqa: E501


        :return: The ipv4_price_hr of this VMDataCenter.  # noqa: E501
        :rtype: Decimal
        """
        return self._ipv4_price_hr

    @ipv4_price_hr.setter
    def ipv4_price_hr(self, ipv4_price_hr):
        """Sets the ipv4_price_hr of this VMDataCenter.


        :param ipv4_price_hr: The ipv4_price_hr of this VMDataCenter.  # noqa: E501
        :type: Decimal
        """

        self._ipv4_price_hr = ipv4_price_hr

    @property
    def network_pricing(self):
        """Gets the network_pricing of this VMDataCenter.  # noqa: E501


        :return: The network_pricing of this VMDataCenter.  # noqa: E501
        :rtype: list[NetworkPriceHr]
        """
        return self._network_pricing

    @network_pricing.setter
    def network_pricing(self, network_pricing):
        """Sets the network_pricing of this VMDataCenter.


        :param network_pricing: The network_pricing of this VMDataCenter.  # noqa: E501
        :type: list[NetworkPriceHr]
        """

        self._network_pricing = network_pricing

    @property
    def region_id(self):
        """Gets the region_id of this VMDataCenter.  # noqa: E501


        :return: The region_id of this VMDataCenter.  # noqa: E501
        :rtype: str
        """
        return self._region_id

    @region_id.setter
    def region_id(self, region_id):
        """Sets the region_id of this VMDataCenter.


        :param region_id: The region_id of this VMDataCenter.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and region_id is None:
            raise ValueError("Invalid value for `region_id`, must not be `None`")  # noqa: E501

        self._region_id = region_id

    @property
    def renewable_energy(self):
        """Gets the renewable_energy of this VMDataCenter.  # noqa: E501


        :return: The renewable_energy of this VMDataCenter.  # noqa: E501
        :rtype: bool
        """
        return self._renewable_energy

    @renewable_energy.setter
    def renewable_energy(self, renewable_energy):
        """Sets the renewable_energy of this VMDataCenter.


        :param renewable_energy: The renewable_energy of this VMDataCenter.  # noqa: E501
        :type: bool
        """
        if self._configuration.client_side_validation and renewable_energy is None:
            raise ValueError("Invalid value for `renewable_energy`, must not be `None`")  # noqa: E501

        self._renewable_energy = renewable_energy

    @property
    def supplier_name(self):
        """Gets the supplier_name of this VMDataCenter.  # noqa: E501


        :return: The supplier_name of this VMDataCenter.  # noqa: E501
        :rtype: str
        """
        return self._supplier_name

    @supplier_name.setter
    def supplier_name(self, supplier_name):
        """Sets the supplier_name of this VMDataCenter.


        :param supplier_name: The supplier_name of this VMDataCenter.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and supplier_name is None:
            raise ValueError("Invalid value for `supplier_name`, must not be `None`")  # noqa: E501

        self._supplier_name = supplier_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(VMDataCenter, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VMDataCenter):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, VMDataCenter):
            return True

        return self.to_dict() != other.to_dict()
